package com.dgtly.notice.service.impl;

import java.util.List;
import com.dgtly.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.dgtly.notice.mapper.NoticeDemandMapper;
import com.dgtly.notice.domain.NoticeDemand;
import com.dgtly.notice.service.INoticeDemandService;
import com.dgtly.common.core.text.Convert;

/**
 * 【请填写功能名称】Service业务层处理
 * 
 * @author dgtly
 * @date 2020-02-13
 */
@Service
public class NoticeDemandServiceImpl implements INoticeDemandService 
{
    @Autowired
    private NoticeDemandMapper noticeDemandMapper;

    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】ID
     * @return 【请填写功能名称】
     */
    @Override
    public NoticeDemand selectNoticeDemandById(Long id)
    {
        return noticeDemandMapper.selectNoticeDemandById(id);
    }

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param noticeDemand 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<NoticeDemand> selectNoticeDemandList(NoticeDemand noticeDemand)
    {
        return noticeDemandMapper.selectNoticeDemandList(noticeDemand);
    }

    /**
     * 新增【请填写功能名称】
     * 
     * @param noticeDemand 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertNoticeDemand(NoticeDemand noticeDemand)
    {
        noticeDemand.setCreateTime(DateUtils.getNowDate());
        return noticeDemandMapper.insertNoticeDemand(noticeDemand);
    }

    /**
     * 修改【请填写功能名称】
     * 
     * @param noticeDemand 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateNoticeDemand(NoticeDemand noticeDemand)
    {
        noticeDemand.setUpdateTime(DateUtils.getNowDate());
        return noticeDemandMapper.updateNoticeDemand(noticeDemand);
    }

    /**
     * 删除【请填写功能名称】对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteNoticeDemandByIds(String ids)
    {
        return noticeDemandMapper.deleteNoticeDemandByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param id 【请填写功能名称】ID
     * @return 结果
     */
    @Override
    public int deleteNoticeDemandById(Long id)
    {
        return noticeDemandMapper.deleteNoticeDemandById(id);
    }

    /**
     * @descption: 获取最新的需求信息前10条
     * @param:
     * @return:
     * @auther: LiuLingChao
     * @date: 2020-2-25 10:19
     */
    @Override
    public List<NoticeDemand> getDemandInfoTenList() {
        return noticeDemandMapper.getDemandInfoTenList();
    }
}
